@@ -1,8 +1,13 @@
 import csv
+import sys
 from trello import TrelloClient
 
+def main() -> None:
+    trello_api_key, trello_token, board_id, file_path = sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4]
+    bulk_import(trello_api_key=trello_api_key, trello_token=trello_token, board_id=board_id, file_path=file_path)
 
-def bulk_import(trello_api_key, trello_token, board_id, file_path):
+
+def bulk_import(trello_api_key: str, trello_token: str, board_id: str, file_path: str) -> None:
     client = TrelloClient(
         api_key=trello_api_key,
         token=trello_token
@@ -25,7 +30,7 @@ def bulk_import(trello_api_key, trello_token, board_id, file_path):
             load = row["Load"]  
 
             checklist_items.append(task + " (" + load +")" )
-            if user_story != category:
+            if user_story != category:  
                 if card is not None and checklist_items :
                     card.add_checklist('Tasks', checklist_items, itemstates=None)
                     checklist_items = []
